@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.24 2003/11/10 01:49:50 gman Exp $ */
+/* $Id: gdict-speller.c,v 1.26 2004/10/22 23:40:11 davyd Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -145,7 +145,6 @@ gdict_speller_init (GDictSpeller *speller) {
     {
         add_atk_namedesc (label, _("Word"), _("Word"));
         add_atk_namedesc (GTK_WIDGET(speller->word_entry), _("Word Entry"), _("Enter a word to know the spelling"));
-        add_atk_relation (GTK_WIDGET(speller->word_entry), label, ATK_RELATION_LABELLED_BY);
     }
       
     speller->hbox = gtk_hbox_new (FALSE, 12);
@@ -179,7 +178,7 @@ gdict_speller_init (GDictSpeller *speller) {
                                     GTK_POLICY_NEVER,
                                     GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_win),
-					 GTK_SHADOW_NONE);
+					 GTK_SHADOW_ETCHED_IN);
     gtk_widget_set_size_request (scrolled_win, 400, 250);
     
     model = gtk_list_store_new (1, G_TYPE_STRING);
