@@ -159,7 +159,7 @@ click_find_cb (GtkWidget	*widget,
 	gtk_widget_set_sensitive (interface.stop_button, FALSE);
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 
-	command = build_search_command ();
+	command = build_search_command (TRUE);
 	
 	if (search_command.lock == FALSE) {
 		spawn_search_command (command);
@@ -230,6 +230,7 @@ remove_constraint_cb (GtkWidget 	*widget,
 	
 	set_constraint_selected_state (constraint->constraint_id, FALSE);	
 	set_constraint_gconf_boolean (constraint->constraint_id, FALSE);	
+	g_free (constraint);
 }
 
 void
@@ -271,7 +272,7 @@ constraint_entry_changed_cb (GtkWidget 	*widget,
 	}
 		
 	look_in_folder_string = 
-		gnome_file_entry_get_full_path(GNOME_FILE_ENTRY(interface.look_in_folder_entry), FALSE);
+		gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (interface.look_in_folder_entry));
 
 	if (look_in_folder_string == NULL) {
 		gtk_widget_set_sensitive (interface.find_button, FALSE);
@@ -373,13 +374,40 @@ open_file_cb (GtkWidget 	*widget,
 				
 			file = g_build_filename (utf8_path, utf8_name, NULL);
 			locale_file = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
+			
+			if (!g_file_test (locale_file, G_FILE_TEST_EXISTS)) {
+		
+				GtkWidget      *dialog;
+				gchar          *primary;
+				gchar          *secondary;
+			
+				primary = g_strdup_printf (_("Could not open document \"%s\"."), 
+			                           g_path_get_basename (utf8_name));
+					
+				secondary = g_strdup  (_("The document does not exist."));
 
-			if (open_file_with_application (locale_file) == FALSE) {
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+			    	                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+								   GTK_MESSAGE_ERROR,
+								   GTK_BUTTONS_OK,
+								   primary,
+								   secondary,
+								   NULL);
+			
+				gtk_dialog_run (GTK_DIALOG (dialog));
+		
+				gtk_tree_selection_unselect_iter (GTK_TREE_SELECTION (interface.selection), &iter);
+				gtk_widget_destroy (GTK_WIDGET(dialog));
+				g_free (primary);
+				g_free (secondary);
+			}
+			else if (open_file_with_application (locale_file) == FALSE) {
 				
 				if (launch_file (locale_file) == FALSE) {
 					
-					if (is_component_action_type (locale_file) 
-			    	    	    && is_nautilus_running ()) {
+					if ((is_nautilus_running ()) &&
+					    ((g_file_test (locale_file, G_FILE_TEST_IS_DIR)) ||
+					     (is_component_action_type (locale_file)))) {
 						open_file_with_nautilus (locale_file);
 					}
 					else {
@@ -801,8 +829,10 @@ file_key_press_event_cb  (GtkWidget 		*widget,
 		     	  gpointer 		data)
 {		
 	if (event->keyval == GDK_space || event->keyval == GDK_Return) {
-		open_file_cb (widget, data);
-		return TRUE;
+		if (event->state != GDK_CONTROL_MASK) {
+			open_file_cb (widget, data);
+			return TRUE;
+		}
 	}
 	else if (event->keyval == GDK_Delete) {
 		move_to_trash_cb (widget, data);
@@ -928,12 +958,39 @@ file_event_after_cb  (GtkWidget 	*widget,
 			file = g_build_filename (utf8_path, utf8_name, NULL);
 			locale_file = g_locale_from_utf8 (file, -1, NULL, NULL, NULL);
 		
-			if (open_file_with_application (locale_file) == FALSE) {
+			if (!g_file_test (locale_file, G_FILE_TEST_EXISTS)) {
+		
+				GtkWidget      *dialog;
+				gchar          *primary;
+				gchar          *secondary;
+			
+				primary = g_strdup_printf (_("Could not open document \"%s\"."), 
+			                           g_path_get_basename (utf8_name));
+					
+				secondary = g_strdup  (_("The document does not exist."));
+
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+			    	                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+								   GTK_MESSAGE_ERROR,
+								   GTK_BUTTONS_OK,
+								   primary,
+								   secondary,
+								   NULL);
+			
+				gtk_dialog_run (GTK_DIALOG (dialog));
+		
+				gtk_tree_selection_unselect_iter (GTK_TREE_SELECTION (interface.selection), &iter);
+				gtk_widget_destroy (GTK_WIDGET(dialog));
+				g_free (primary);
+				g_free (secondary);
+			}
+			else if (open_file_with_application (locale_file) == FALSE) {
 				
 				if (launch_file (locale_file) == FALSE) {
 				
-					if (is_component_action_type (locale_file) 
-					    && is_nautilus_running ()) {
+					if ((is_nautilus_running ()) &&
+					    ((g_file_test (locale_file, G_FILE_TEST_IS_DIR)) ||
+					     (is_component_action_type (locale_file)))) {
 						open_file_with_nautilus (locale_file);
 					}
 					else {
@@ -1392,26 +1449,20 @@ key_press_cb (GtkWidget    	*widget,
 	return FALSE;
 }
 
-gboolean
-look_in_folder_key_press_cb (GtkWidget    	*widget, 
-		     	     GdkEventKey	*event, 
-		     	     gpointer 		data)
-{
-	g_return_val_if_fail (GTK_IS_WIDGET(widget), FALSE);
-
-	if (event->keyval == GDK_Return)
-	{
-		if ((GTK_WIDGET_VISIBLE (interface.find_button)) && 
-		    (GTK_WIDGET_SENSITIVE (interface.find_button))) {
-			click_find_cb (interface.find_button, NULL);
-		}
-	}
-	return FALSE;
-}
-
 gboolean
 not_running_timeout_cb (gpointer data)
 {
 	search_command.not_running_timeout = FALSE;
 	return FALSE;
 }
+
+void
+disable_quick_search_cb (GtkWidget 	*dialog, 
+                         gint      	response, 
+                         gpointer   	data)
+{
+	if (response == GTK_RESPONSE_OK) {
+		gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/disable_quick_search", TRUE);
+	}
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+}
