@@ -43,7 +43,6 @@
  * -------------------
  */
 
-int IsLeapYear (int);
 int match_line_in_db (LogLine *line, GList *db);
 void UpdateLastPage (Log *log);
 
@@ -224,8 +223,6 @@ OpenLogFile (char *filename)
       (tlog->lines)[tlog->total_lines - 1] = line;
    }
 
-   tlog->mon_on = FALSE;
-
    /* Read log stats */
    ReadLogStats (tlog);
 
@@ -238,6 +235,7 @@ OpenLogFile (char *filename)
    /* initialize date headers hash table */
    tlog->date_headers = g_hash_table_new_full (
                 NULL, NULL, NULL, (GDestroyNotify) gtk_tree_path_free);
+   tlog->first_time = TRUE;
    return tlog;
 
 }
