@@ -21,62 +21,32 @@
 
 
 #include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "logview.h"
 
 extern ConfigData *cfg;
-extern GtkWidget *app;
+extern GtkWidget *window;
 
 static gboolean queue_err_messages = FALSE;
 static GList *msg_queue = NULL;
 
-PangoFont *
-LoadFont (PangoContext *context, PangoFontDescription *fontd)
-{
-	PangoFont *font;
-
-	font = pango_context_load_font (context, fontd);
-	if (font == NULL) {
-		PangoFontDescription *d;
-		d = (PangoFontDescription *)
-			pango_font_description_from_string ("fixed 10"); 
-		font = pango_context_load_font (context, d);
-		pango_font_description_free (d);
-	}
-	if (font == NULL) {
-		PangoFontDescription *d;
-		d = (PangoFontDescription *)
-			pango_font_description_from_string ("Sans 10"); 
-		font = pango_context_load_font (context, d);
-		pango_font_description_free (d);
-	}
-	if (font == NULL) {
-		GtkWidget *msgbox;
-		msgbox = gnome_message_box_new (_("Cannot load required fonts, "
-						  "cannot continue"),
-						GNOME_MESSAGE_BOX_ERROR,
-						GNOME_STOCK_BUTTON_OK, NULL);
-		if (app != NULL)
-			gnome_dialog_set_parent (GNOME_DIALOG (msgbox), GTK_WINDOW (app));
-		gtk_window_set_modal (GTK_WINDOW(msgbox), TRUE); 
-		gtk_widget_show (msgbox);
-		gnome_dialog_run (GNOME_DIALOG (msgbox));
-		exit (1);
-	}
-	return font;
-}
 
 static void
 MakeErrorDialog (const char *msg)
 {
-	GtkWidget *msgbox;
-	msgbox = gnome_message_box_new (msg, GNOME_MESSAGE_BOX_ERROR,
-					GNOME_STOCK_BUTTON_OK, NULL);
-	if (app != NULL)
-		gnome_dialog_set_parent (GNOME_DIALOG (msgbox), GTK_WINDOW (app));
-	gtk_window_set_modal (GTK_WINDOW(msgbox), TRUE); 
-	gtk_widget_show (msgbox);
+	GtkWidget *dialog;
+	dialog = gtk_message_dialog_new (NULL,
+					 GTK_DIALOG_MODAL,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_OK,
+					 msg);
+	g_signal_connect (G_OBJECT (dialog), "response",
+			  G_CALLBACK (gtk_widget_destroy),
+			  NULL);
+
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_widget_show (dialog);
 }
 
 /* ----------------------------------------------------------------------
@@ -88,8 +58,6 @@ MakeErrorDialog (const char *msg)
 void
 ShowErrMessage (const char *msg)
 {
-  DB (printf(_("Error: [%s]\n"), msg));
-
   if (queue_err_messages) {
 	  msg_queue = g_list_append (msg_queue, g_strdup (msg));
   } else {
