@@ -26,6 +26,8 @@
 #include <sys/stat.h>
 #include "logview.h"
 #include "gnome.h"
+#include "zoom.h"
+#include "misc.h"
 
 /*
  *  --------------------------
@@ -33,45 +35,44 @@
  *  --------------------------
  */
 
-int zoom_visible;
-GtkWidget *zoom_dialog;
-static GtkWidget *scrolled_window = NULL;
-
-extern Log *curlog;
 extern char *month[12];
 extern GList *regexp_db, *descript_db;
-extern GnomeUIInfo view_menu[];
 
-void close_zoom_view (GtkWidget *widget, gpointer data);
-void quit_zoom_view (GtkWidget *widget, gpointer data);
-void create_zoom_view (void);
 int match_line_in_db (LogLine *line, GList *db);
 
+
+void
+zoom_close_button (GtkWidget *zoom_dialog, int arg, gpointer data)
+{
+	LogviewWindow *window = data;
+	close_zoom_view (window);
+}
+
 /* ----------------------------------------------------------------------
    NAME:          create_zoom_view
    DESCRIPTION:   Display the statistics of the log.
    ---------------------------------------------------------------------- */
 
 void
-create_zoom_view (void)
+create_zoom_view (LogviewWindow *window)
 {
 
-   if (curlog == NULL || zoom_visible)
+   if (window->curlog == NULL || window->zoom_visible)
       return;
 
-   if (zoom_dialog == NULL) {
+   if (window->zoom_dialog == NULL) {
+	GtkWidget *zoom_dialog;
    	zoom_dialog  = gtk_dialog_new_with_buttons (_("Entry Detail"), 
 					       	    GTK_WINDOW_TOPLEVEL, 
 					            GTK_DIALOG_DESTROY_WITH_PARENT,
 					            GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, 
 					            NULL);
-        /* FIXME: no need to pass zoom_dialog - its global !! */ 
         g_signal_connect (G_OBJECT (zoom_dialog), "response",
-		          G_CALLBACK (close_zoom_view),
-			  &zoom_dialog);
+		          G_CALLBACK (zoom_close_button),
+			  window);
    	g_signal_connect (G_OBJECT (zoom_dialog), "destroy",
 		          G_CALLBACK (quit_zoom_view),
-			  &zoom_dialog);
+			  window);
         g_signal_connect (G_OBJECT (zoom_dialog), "delete_event",
 		          G_CALLBACK (gtk_true),
 			  NULL);
@@ -79,11 +80,12 @@ create_zoom_view (void)
 	gtk_window_set_default_size (GTK_WINDOW (zoom_dialog), 500, 225);
 	gtk_dialog_set_default_response (GTK_DIALOG (zoom_dialog), GTK_RESPONSE_CLOSE);
    	gtk_container_set_border_width (GTK_CONTAINER (zoom_dialog), 5);
+	window->zoom_dialog = zoom_dialog;
    }
-   
-   repaint_zoom();
-   gtk_widget_show (zoom_dialog);
-   zoom_visible = TRUE; 
+
+   repaint_zoom(window);
+   gtk_widget_show (window->zoom_dialog);
+   window->zoom_visible = TRUE; 
 }
 
 /* ----------------------------------------------------------------------
@@ -92,12 +94,11 @@ create_zoom_view (void)
    ---------------------------------------------------------------------- */
 
 int
-repaint_zoom (void)
+repaint_zoom (LogviewWindow *window)
 {
    static GtkWidget *zoom_tree;
    static GtkCellRenderer *renderer;
    static GtkTreeViewColumn *column1, *column2;
-   static GtkListStore *store;
    const gchar *titles[] = { N_("Date:"), N_("Process:"),
                 N_("Message:"), N_("Description:"), NULL }; 
    GtkTreeIter iter;
@@ -106,72 +107,79 @@ repaint_zoom (void)
    char buffer[1024];
    char *utf8;
    gint i;
+   GtkWidget *zoom_dialog = window->zoom_dialog;
 
-   if (scrolled_window == NULL) {
+   g_return_if_fail (window->curlog);
 
-       scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-       gtk_widget_set_sensitive (scrolled_window, TRUE);
-       gtk_container_set_border_width (GTK_CONTAINER (scrolled_window), 5);
-       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-                                       GTK_POLICY_AUTOMATIC,
-                                       GTK_POLICY_AUTOMATIC);
-       gtk_box_pack_start (GTK_BOX (GTK_DIALOG (zoom_dialog)->vbox),
-                           scrolled_window, TRUE, TRUE, 0);
+   if (window->zoom_scrolled_window == NULL) {
+	   GtkWidget *scrolled_window;
+	   GtkListStore *store;
+   
+	   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+	   gtk_widget_set_sensitive (scrolled_window, TRUE);
+	   gtk_container_set_border_width (GTK_CONTAINER (scrolled_window), 5);
+	   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+					   GTK_POLICY_AUTOMATIC,
+					   GTK_POLICY_AUTOMATIC);
 
-       store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
-       zoom_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
-       gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (zoom_tree), TRUE); 
+	   store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+	   zoom_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+	   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (zoom_tree), TRUE); 
 
-       gtk_container_add (GTK_CONTAINER (scrolled_window), zoom_tree);
+	   gtk_container_add (GTK_CONTAINER (scrolled_window), zoom_tree);
 
-       /* Create Columns */
-       renderer = gtk_cell_renderer_text_new ();
-       column1 = gtk_tree_view_column_new_with_attributes (_("Log Line Details"),
-                    renderer, "text", 0, NULL);
-       gtk_tree_view_column_set_sizing (column1, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-       gtk_tree_view_column_set_resizable (column1, TRUE); 
-       gtk_tree_view_append_column (GTK_TREE_VIEW (zoom_tree), column1);
-       gtk_tree_view_column_set_spacing (column1, 12);
+	   /* Create Columns */
+	   renderer = gtk_cell_renderer_text_new ();
+	   column1 = gtk_tree_view_column_new_with_attributes (_("Log Line Details"),
+							       renderer, "text", 0, NULL);
+	   gtk_tree_view_column_set_sizing (column1, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	   gtk_tree_view_column_set_resizable (column1, TRUE); 
+	   gtk_tree_view_append_column (GTK_TREE_VIEW (zoom_tree), column1);
+	   gtk_tree_view_column_set_spacing (column1, 12);
   
-       renderer = gtk_cell_renderer_text_new ();
-       column2 = gtk_tree_view_column_new_with_attributes ("", renderer,
-                    "text", 1, NULL);
-       gtk_tree_view_column_set_sizing (column2, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-       gtk_tree_view_column_set_resizable (column2, TRUE); 
-       gtk_tree_view_append_column (GTK_TREE_VIEW (zoom_tree), column2);
-       gtk_tree_view_column_set_spacing (column2, 12);
-
-       /* Add entries to the list */
-       for (i = 0; titles[i]; ++i) {
-           gtk_list_store_append (GTK_LIST_STORE (store), &iter);
-           gtk_list_store_set (GTK_LIST_STORE (store), &iter, 0, _(titles[i]), -1);
-       }
+	   renderer = gtk_cell_renderer_text_new ();
+	   column2 = gtk_tree_view_column_new_with_attributes ("", renderer,
+							       "text", 1, NULL);
+	   gtk_tree_view_column_set_sizing (column2, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	   gtk_tree_view_column_set_resizable (column2, TRUE); 
+	   gtk_tree_view_append_column (GTK_TREE_VIEW (zoom_tree), column2);
+	   gtk_tree_view_column_set_spacing (column2, 12);
 
+	   /* Add entries to the list */
+	   for (i = 0; titles[i]; ++i) {
+		   gtk_list_store_append (GTK_LIST_STORE (store), &iter);
+		   gtk_list_store_set (GTK_LIST_STORE (store), &iter, 0, _(titles[i]), -1);
+	   }
+	   
+	   window->zoom_scrolled_window = scrolled_window;
+	   window->zoom_store = store;
+	   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window->zoom_dialog)->vbox),
+			       scrolled_window, TRUE, TRUE, 0);
    }
 
-   if (curlog != NULL)
-       g_snprintf (buffer, sizeof (buffer), "%s", curlog->name);
+   if (window->curlog != NULL)
+       g_snprintf (buffer, sizeof (buffer), "%s", window->curlog->name);
    else
        g_snprintf (buffer, sizeof (buffer), _("<No log loaded>"));
    gtk_tree_view_column_set_title (column2, buffer);
 
-   gtk_widget_show_all (scrolled_window);
+   gtk_widget_show_all (window->zoom_scrolled_window);
 
    /* Check that there is at least one log */
-   if (curlog == NULL) {
-       gtk_list_store_clear (GTK_LIST_STORE (store));
+   if (window->curlog == NULL) {
+       gtk_list_store_clear (GTK_LIST_STORE (window->zoom_store));
        /* Add entries to the list */
        for (i = 0; titles[i]; ++i) {
-           gtk_list_store_append (GTK_LIST_STORE (store), &iter);
-           gtk_list_store_set (GTK_LIST_STORE (store), &iter, 0, _(titles[i]), -1);
+           gtk_list_store_append (GTK_LIST_STORE (window->zoom_store), &iter);
+           gtk_list_store_set (GTK_LIST_STORE (window->zoom_store), &iter, 0, _(titles[i]), -1);
        }
        return FALSE;
    }
   
-   if (gtk_tree_model_get_iter_root (GTK_TREE_MODEL (store), &iter)) {
+   if (gtk_tree_model_get_iter_root (GTK_TREE_MODEL (window->zoom_store), &iter)) {
 
-       if (curlog->current_line_no <= 0 || 
-           ((line = (curlog->lines)[curlog->current_line_no - 1]) == NULL)) {
+       if (window->curlog->current_line_no <= 0 || 
+           ((line = (window->curlog->lines)[window->curlog->current_line_no]) == NULL)) {
        	   return FALSE;
        }
 
@@ -196,24 +204,24 @@ repaint_zoom (void)
            utf8 = LocaleToUTF8 (buffer);
        }
 
-       gtk_list_store_set (GTK_LIST_STORE (store), &iter, 1, utf8, -1);
+       gtk_list_store_set (GTK_LIST_STORE (window->zoom_store), &iter, 1, utf8, -1);
        g_free (utf8);
 
-       gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
+       gtk_tree_model_iter_next (GTK_TREE_MODEL (window->zoom_store), &iter);
        utf8 = LocaleToUTF8 (line->process);
-       gtk_list_store_set (GTK_LIST_STORE (store), &iter, 1, utf8, -1);
+       gtk_list_store_set (GTK_LIST_STORE (window->zoom_store), &iter, 1, utf8, -1);
        g_free (utf8);
 
-       gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
+       gtk_tree_model_iter_next (GTK_TREE_MODEL (window->zoom_store), &iter);
        utf8 = LocaleToUTF8 (line->message);
-       gtk_list_store_set (GTK_LIST_STORE (store), &iter, 1, utf8, -1);
+       gtk_list_store_set (GTK_LIST_STORE (window->zoom_store), &iter, 1, utf8, -1);
        g_free (utf8);
 
-       gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
+       gtk_tree_model_iter_next (GTK_TREE_MODEL (window->zoom_store), &iter);
        if (match_line_in_db (line, regexp_db))
            if (find_tag_in_db (line, descript_db)) {
                utf8 = LocaleToUTF8 (line->description->description);
-               gtk_list_store_set (GTK_LIST_STORE (store), &iter, 1, utf8, -1);
+               gtk_list_store_set (GTK_LIST_STORE (window->zoom_store), &iter, 1, utf8, -1);
                g_free (utf8);
        }
                
@@ -224,28 +232,30 @@ repaint_zoom (void)
 }
 
 /* ----------------------------------------------------------------------
-   NAME:          CloseLogInfo
+   NAME:          close zoom view
    DESCRIPTION:   Callback called when the log info window is closed.
    ---------------------------------------------------------------------- */
 
 void
-close_zoom_view (GtkWidget *widget, gpointer data)
+close_zoom_view (LogviewWindow *window)
 {
-   if (zoom_visible) {
-      gtk_widget_hide (GTK_WIDGET (zoom_dialog));
-      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view_menu[1].widget), FALSE);
-/*
-      if (G_IS_OBJECT (zoom_layout))
-         g_object_unref (G_OBJECT (zoom_layout)); */ 
+   if (window->zoom_visible) {
+      gtk_widget_hide (GTK_WIDGET (window->zoom_dialog));
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
+				      (gtk_ui_manager_get_widget 
+				       (window->ui_manager, "/LogviewMenu/ViewMenu/ShowDetails")),
+				      FALSE);
+      window->zoom_dialog = NULL;
+      window->zoom_scrolled_window = NULL;
+      window->zoom_visible = FALSE;
    }
-   zoom_dialog = NULL;
-   scrolled_window = NULL;
-   zoom_visible = FALSE;
 }
 
 void
-quit_zoom_view (GtkWidget *widget, gpointer data) {
- 
-	zoom_dialog = NULL;
-	scrolled_window = NULL;
+quit_zoom_view (GtkWidget *zoom_dialog, gpointer data) {
+	LogviewWindow *window = data;
+	window->zoom_dialog = NULL;
+	window->zoom_scrolled_window = NULL;
+	window->zoom_visible = FALSE;
 }
+
